# Comment


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**topic_guid** | **str** |  | [readonly] 
**modified_date** | **datetime** |  | [readonly] 
**guid** | **str** |  | [optional] 
**date** | **datetime** |  | [optional] 
**author** | **str, none_type** |  | [optional] 
**comment** | **str** |  | [optional] 
**viewpoint_guid** | **str, none_type** |  | [optional] 
**reply_to_comment_guid** | **str, none_type** |  | [optional] 
**modified_author** | **str, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


